A module containing grids wrapped around spheres.
Structs
- Cube
Sphere Grid - A grid that wraps a cube around a sphere in order to determine grid positions.
- Cube
Sphere Point - A point on a
CubeSphereGrid. - Rectangle
Sphere Grid - A grid for a sphere based on the equirectangular projection.
- Rectangle
Sphere Point - A point on a
RectangleSphereGrid.
Traits
- Sphere
Point - A point on a spherical grid.